@@ -180,7 +180,7 @@
 
       END IF
 ***
-*      CALL SGCLST(clrmap)
+      CALL SGCLST(clrmap)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -233,7 +233,6 @@
 
 *     / CLOSE PAGE ( OR SCREEN ) /
 
-      IF (IWS.EQ.3) CALL Z1PCLS
 
       NPAGE=NPAGE+1
       CMSG='GRPH1 : PAGE = ### COMPLETED.'
@@ -244,6 +243,7 @@
       CALL SWLGET('LDUMP  ', LDUMP )
       IF (IWS.EQ.1) CALL ZMPCLS (LWAIT, LDUMP)
       IF (IWS.EQ.2) CALL ZMPCLS (.FALSE., .FALSE.)
+      IF (IWS.EQ.3) CALL Z1PCLS
       IF (IWS.EQ.4) CALL ZGPCLS
 
       RETURN
@@ -348,6 +348,7 @@
       IF (IWS.EQ.1) CALL ZMSLCL(NCOLOR)
       IF (IWS.EQ.2) CALL ZMSLCL(NCOLOR)
       IF (IWS.EQ.3) CALL Z1SLCL(NCOLOR)
+      IF (IWS.EQ.4) CALL ZGSLCL(NCOLOR)
 
 *      ENDIF
 
@@ -420,6 +421,7 @@
       IF (IWS.EQ.1) CALL ZMQTNC(LTNATR)
       IF (IWS.EQ.2) CALL ZMQTNC(LTNATR)
       IF (IWS.EQ.3) CALL Z1QTNC(LTNATR)
+      IF (IWS.EQ.4) CALL ZGQTNC(LTNATR)
 
       RETURN
 *-----------------------------------------------------------------------
@@ -584,7 +586,7 @@
 
       IF (IWS.EQ.1) CALL ZMCLINI(CLRMAP)
       IF (IWS.EQ.2) CALL ZMCLINI(CLRMAP)
-*      IF (IWS.EQ.3) CALL Z1CLINI(ICNUM)
+      IF (IWS.EQ.3) CALL Z1CLINI(CLRMAP)
       IF (IWS.EQ.4) CALL ZGCLINI(CLRMAP,LFGBG)
 
       RETURN
