@@ -1,14 +1,13 @@
 *-----------------------------------------------------------------------
-*     LOGICAL PARAMETER CONTROL
-*-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     SWLQNP / SWLQID / SWLQCP / SWLQVL / SWLSVL
 *-----------------------------------------------------------------------
       SUBROUTINE SWLQNP(NCP)
-
-      LOGICAL   LPARA
+      INTEGER   NCP
       CHARACTER CP*(*)
-      PARAMETER (NPARA = 11)
-      LOGICAL   LX(NPARA)
+
+      PARAMETER (NPARA = 12)
+
+      LOGICAL   LX(NPARA), LPARA
       LOGICAL   LCHREQ, LFIRST
       CHARACTER CPARAS(NPARA)*8
       CHARACTER CPARAL(NPARA)*40
@@ -18,35 +17,34 @@
 
       SAVE
 
-*     / SHORT NAME /
-
-      DATA      CPARAS( 1) / 'LWAIT   ' / , LX( 1) / .TRUE. /
-      DATA      CPARAS( 2) / 'LWAIT0  ' / , LX( 2) / .FALSE. /
-      DATA      CPARAS( 3) / 'LWAIT1  ' / , LX( 3) / .TRUE. /
-      DATA      CPARAS( 4) / 'LKEY    ' / , LX( 4) / .TRUE. /
-      DATA      CPARAS( 5) / 'LDUMP   ' / , LX( 5) / .FALSE. /
-      DATA      CPARAS( 6) / 'LALT    ' / , LX( 6) / .FALSE. /
-      DATA      CPARAS( 7) / 'LCOLOR  ' / , LX( 7) / .TRUE. /
-      DATA      CPARAS( 8) / 'LSEP    ' / , LX( 8) / .FALSE. /
-      DATA      CPARAS( 9) / 'LPRINT  ' / , LX( 9) / .FALSE. /
+* ---- SHORT NAME ----
+      DATA      CPARAS(1)  / 'LWAIT   ' / , LX(1)  / .TRUE. /
+      DATA      CPARAS(2)  / 'LWAIT0  ' / , LX(2)  / .FALSE. /
+      DATA      CPARAS(3)  / 'LWAIT1  ' / , LX(3)  / .TRUE. /
+      DATA      CPARAS(4)  / 'LKEY    ' / , LX(4)  / .TRUE. /
+      DATA      CPARAS(5)  / 'LDUMP   ' / , LX(5)  / .FALSE. /
+      DATA      CPARAS(6)  / 'LALT    ' / , LX(6)  / .FALSE. /
+      DATA      CPARAS(7)  / 'LCOLOR  ' / , LX(7)  / .TRUE. /
+      DATA      CPARAS(8)  / 'LSEP    ' / , LX(8)  / .FALSE. /
+      DATA      CPARAS(9)  / 'LPRINT  ' / , LX(9)  / .FALSE. /
       DATA      CPARAS(10) / 'LWND    ' / , LX(10) / .TRUE. /
       DATA      CPARAS(11) / 'LFGBG   ' / , LX(11) / .FALSE. /
-
-*     / LONG NAME /
-
-      DATA      CPARAL( 1) / 'WAIT' /
-      DATA      CPARAL( 2) / 'WAIT_OPENING' /
-      DATA      CPARAL( 3) / 'WAIT_CLOSING' /
-      DATA      CPARAL( 4) / 'KEYCLICK' /
-      DATA      CPARAL( 5) / 'DUMP' /
-      DATA      CPARAL( 6) / 'ALTERNATE' /
-      DATA      CPARAL( 7) / 'ENABLE_COLOR_PS' /
-      DATA      CPARAL( 8) / 'SEPARATE' /
-      DATA      CPARAL( 9) / 'PRINT' /
+      DATA      CPARAS(12) / 'LCMCH   ' / , LX(12) / .FALSE. /
+* ---- LONG NAME ----
+      DATA      CPARAL(1)  / 'WAIT' /
+      DATA      CPARAL(2)  / 'WAIT_OPENING' /
+      DATA      CPARAL(3)  / 'WAIT_CLOSING' /
+      DATA      CPARAL(4)  / 'KEYCLICK' /
+      DATA      CPARAL(5)  / 'DUMP' /
+      DATA      CPARAL(6)  / 'ALTERNATE' /
+      DATA      CPARAL(7)  / 'ENABLE_COLOR_PS' /
+      DATA      CPARAL(8)  / 'SEPARATE' /
+      DATA      CPARAL(9)  / 'PRINT' /
       DATA      CPARAL(10) / 'SHOW_WINDOW' /
       DATA      CPARAL(11) / '****LFGBG   ' /
-      DATA      LFIRST / .TRUE. /
+      DATA      CPARAL(12) / 'CMAP_CHANGABLE' / 
 
+      DATA      LFIRST / .TRUE. /
 
       NCP = NPARA
 
@@ -55,7 +53,8 @@
       ENTRY SWLQID(CP, IDX)
 
       DO 10 N = 1, NPARA
-        IF (LCHREQ(CP, CPARAS(N)) .OR. LCHREQ(CP, CPARAL(N))) THEN
+        IF (LCHREQ(CP, CPARAS(N))
+     &        .OR. LCHREQ(CP, CPARAL(N))) THEN
           IDX = N
           RETURN
         END IF
@@ -90,7 +89,7 @@
       IF (LFIRST) THEN
         CALL RTLGET('SW', CPARAS, LX, NPARA)
         CALL RLLGET(CPARAL, LX, NPARA)
-        LFIRST = .FALSE.
+        LFIRST=.FALSE.
       END IF
 
       IF (1.LE.IDX .AND. IDX.LE.NPARA) THEN
@@ -120,11 +119,12 @@
       ENTRY SWLQIN(CP, IN)
 
       DO 20 N = 1, NPARA
-        IF (LCHREQ(CP, CPARAS(N)) .OR. LCHREQ(CP, CPARAL(N))) THEN
-          IN = N
-          RETURN
-        END IF
-   20 CONTINUE
+         IF (LCHREQ(CP, CPARAS(N)) .OR.
+     &        LCHREQ(CP, CPARAL(N))) THEN
+            IN = N
+            RETURN
+         ENDIF
+ 20   CONTINUE
 
       IN = 0
 
