@@ -374,9 +374,7 @@
      +   CALL MSGDMP('E', 'SWIOPN', CNOPN)
       IF (IWS.EQ.1) CALL ZXIOPN(IWX, IWY, IMW, IMH)
       IF (IWS.EQ.2) THEN
-*        WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4
-*         Makes Segmentation Fault
-*        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
+        CALL Z1CLIP(WX1, WY1, WX2, WY2, WX3, WY3, WX4, WY4)
         CALL Z1IOPN(IWX, IWY, IMW, IMH)
       ENDIF
       IF (IWS.EQ.3) CALL ZTIOPN(IWX, IWY, IMW, IMH)
@@ -558,7 +556,7 @@
       CALL SWCSET('CLRMAP',CMAP)
       CALL SWQFNM('CLRMAP ', CLRMAP)
       IF (CLRMAP.EQ.' ') THEN
-        CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXISIT.')
+        CALL MSGDMP('E','SWDOPN','COLORMAP FILE DOES NOT EXIST.')
       END IF
 
       IF (IWS.EQ.1) CALL ZXCLINI(CLRMAP,LFGBG)
